==> cmsmadesimple-1.5.3.tgz: cms/modules/TinyMCE/tinymce/jscripts/tiny_mce/plugins/advlink/langs/cs_dlg.js <==
tinyMCE.addI18n('cs.advlink_dlg',{
title:"Vlo\u017Eit/upravit odkaz",
url:"URL odkazu",
target:"C\u00EDl",
titlefield:"Titulek",
is_email:"Zadan\u00E9 URL vypad\u00E1 jako emailov\u00E1 adresa, chcete doplnit pot\u0159ebn\u00FD prefix mailto: ?",
is_external:"Zadan\u00E9 URL vypad\u00E1 jako extern\u00ED odkaz, chtete doplnit pot\u0159ebn\u00FD prefix http:// ?",
list:"Seznam odkaz\u016F",
general_tab:"Hlavn\u00ED",
popup_tab:"Popup",
events_tab:"Ud\u00E1losti",
advanced_tab:"Pokro\u010Dil\u00E9",
general_props:"Hlavn\u00ED nastaven\u00ED",
popup_props:"Vlastnosti vyskakovac\u00EDho okna",
event_props:"Ud\u00E1losti",
advanced_props:"Pokro\u010Dil\u00E9 nastaven\u00ED",
popup_opts:"Volby",
anchor_names:"Kotva",
target_same:"Otev\u0159\u00EDt v tomto okn\u011B / r\u00E1mu",
target_parent:"Otev\u0159\u00EDt v rodi\u010Dovsk\u00E9m okn\u011B / r\u00E1mu",
target_top:"Otev\u0159\u00EDt v hlavn\u00EDm r\u00E1mu (nahradit v\u0161echny r\u00E1my)",
target_blank:"Otev\u0159\u00EDt v nov\u00E9m okn\u011B",
popup:"Javascript popup",
popup_url:"URL vyskakovac\u00EDho okna",
popup_name:"Jm\u00E9no okna",
popup_return:"Vlo\u017Eit 'return false'",
popup_scrollbars:"Zobrazit posuvn\u00EDky",
popup_statusbar:"Zobrazit stavov\u00FD \u0159\u00E1dek",
popup_toolbar:"Zobrazit n\u00E1strojovou li\u0161tu",
popup_menubar:"Zobrazit menu",
popup_location:"Zobrazit pole s adresou",
popup_resizable:"Umo\u017Enit zm\u011Bnu velikosti vytvo\u0159en\u00E9ho okna",
popup_dependent:"Z\u00E1vislost (pouze Mozilla/Firefox)",
popup_size:"Velikost",
popup_position:"Pozice (X/Y)",
id:"ID",
style:"Styl",
classes:"T\u0159\u00EDdy",
target_name:"Jm\u00E9no c\u00EDle",
langdir:"Sm\u011Br textu",
target_langcode:"Jazyk c\u00EDle",
langcode:"K\u00F3d jazyka",
encoding:"K\u00F3dov\u00E1n\u00ED",
mime:"MIME type c\u00EDle",
rel:"Vztah str\u00E1nky k c\u00EDli",
rev:"Vztah c\u00EDle ke str\u00E1nce",
tabindex:"Tabul\u00E1tor",
accesskey:"P\u0159\u00EDstupov\u00E1 kl\u00E1vesa",
ltr:"Zleva doprava",
rtl:"Zprava doleva",
link_list:"Seznam odkaz\u016F"
});

==> cmsmadesimple-1.6.6.tgz: cms/modules/TinyMCE/tinymce/jscripts/tiny_mce/plugins/advlink/langs/cs_dlg.js <==
tinyMCE.addI18n('cs.advlink_dlg',{
title:"Vlo\u017Eit/upravit odkaz",
url:"URL odkazu",
target:"C\u00EDl",
titlefield:"Titulek",
is_email:"Zadan\u00E9 URL vypad\u00E1 jako e-mailov\u00E1 adresa, chcete doplnit prefix mailto:?",
is_external:"Zadan\u00E9 URL vypad\u00E1 jako extern\u00ED odkaz, chtete doplnit prefix http://?",
list:"Seznam odkaz\u016F",
general_tab:"Hlavn\u00ED",
popup_tab:"Vyskakovac\u00ED okno",
events_tab:"Ud\u00E1losti",
advanced_tab:"Pokro\u010Dil\u00E9",
general_props:"Hlavn\u00ED nastaven\u00ED",
popup_props:"Vlastnosti vyskakovac\u00EDho okna",
event_props:"Ud\u00E1losti",
advanced_props:"Pokro\u010Dil\u00E9 nastaven\u00ED",
popup_opts:"Volby",
anchor_names:"Kotva",
target_same:"Otev\u0159\u00EDt v tomto okn\u011B/r\u00E1mu",
target_parent:"Otev\u0159\u00EDt v nad\u0159azen\u00E9m okn\u011B/r\u00E1mu",
target_top:"Otev\u0159\u00EDt v hlavn\u00EDm okn\u011B/r\u00E1mu (nahradit v\u0161echny r\u00E1my)",
target_blank:"Otev\u0159\u00EDt v nov\u00E9m okn\u011B/r\u00E1mu",
popup:"Javascriptov\u00E9 okno",
popup_url:"URL vyskakovac\u00EDho okna",
popup_name:"N\u00E1zev okna",
popup_return:"Vlo\u017Eit 'return false'",
popup_scrollbars:"Zobrazit posuvn\u00EDky",
popup_statusbar:"Zobrazit stavov\u00FD \u0159\u00E1dek",
popup_toolbar:"Zobrazit n\u00E1strojovou li\u0161tu",
popup_menubar:"Zobrazit menu",
popup_location:"Zobrazit pole s adresou",
popup_resizable:"Umo\u017Enit zm\u011Bnu velikosti vytvo\u0159en\u00E9ho okna",
popup_dependent:"Z\u00E1vislost (pouze Mozilla/Firefox)",
popup_size:"Velikost",
popup_position:"Pozice (X/Y)",
id:"ID",
style:"Styl",
classes:"T\u0159\u00EDdy",
target_name:"N\u00E1zev c\u00EDle",
langdir:"Sm\u011Br textu",
target_langcode:"Jazyk c\u00EDle",
langcode:"K\u00F3d jazyka",
encoding:"K\u00F3dov\u00E1n\u00ED",
mime:"MIME typ",
rel:"rel",
rev:"rev",
tabindex:"Tabindex",
accesskey:"P\u0159\u00EDstupov\u00E1 kl\u00E1vesa",
ltr:"Zleva doprava",
rtl:"Zprava doleva",
link_list:"Seznam odkaz\u016F"
});
